# Кодекс поведения

## Договоренности

В интересах создания открытой и гостеприимной среды мы, как участники проекта, обязуемся сделать участие в нашем 
сообществе свободным от предрасудков и дескриминации для всех, независимо от возраста, внешниго вида, этнической 
принадлежности, вероисповидания, расы, национальности и уровня опыта.

## Стандарты

Примерами поведения, которое способствует созданию гостеприимной среды, являются:

* Использование нормативной, дружелюбной речи и письма
* Уважительное отношение к различным точкам зрения и опыту
* Gracefully accepting constructive criticism
* Адекватное восприятие конструктивной критики
* Проявление эмпатии к другим участникам сообщества

Примерами неприемлемого поведения участников являются:

* Использование ненормативной лексики, иных материалов непристойного характера или политической направленности
* Троллинг, оскорбительные/уничижительные комментарии, а также переход на личности
* Публичное или персональное преследование
* Публикация личной информации других людей, такой как адресные данные, без явного разрешения
* Иное поведение, которое можно обоснованно считать неуместным в профессиональной среде

## Обязательства

Ответственные за сопровождение проекта отвечают за актуализацию стандартов приемлемого поведения. Также ожидается, что 
они предпримут соответствующие справедливые действия в ответ на любые случаи неприемлемого поведения.

Ответственные за сопровождение проекта имеют право и обязаны удалять, редактировать или отклонять код, содержащиий 
информацию, которые не соответствуют настоящему Кодексу поведения, или временно или навсегда заблокировать любого 
участника за иное поведение, которое они считают неуместными, оскорбительными или вредными для сообщества проекта.

## Область применения

Этот Кодекс поведения применяется как внутри компании, так и за ее пределами, когда человек представляет проект или его 
сообщество. Демонстрация проекта или материалов, связанных с ним, должны включать официальный адрес проекта. 
Представление проекта может быть дополнительно определено и уточнено ответственными за сопровождение проекта.

## Правоприменение

О случаях оскорбительного, агрессивного или иного неприемлемого поведения можно сообщить, связавшись с командой проекта. 
Команда проекта рассмотрит и расследует все жалобы и отреагирует так, как сочтет нужным в данных обстоятельствах. 
Команда проекта обязана сохранять конфиденциальность в отношении лица, сообщившего об инциденте. Дополнительные сведения 
о конкретных политиках правоприменения могут быть опубликованы отдельно.

Ответственные за сопровождение проекта, которые не соблюдают или не обеспечивают добросовестное соблюдение Кодекса 
поведения, могут быть временно или на постоянной основе отстранены от участия в проекте.

## Дополнительная информация

Данный Кодекс поведения является адаптацией 
[Соглашения участников проекта](http://contributor-covenant.org/version/1/4), версия 1.4.
